DRAM Energy
===========

:Version info:
    .. image:: https://img.shields.io/pypi/v/energydram
        :target: https://pypi.org/project/energydram/

:Compatibility:
    .. image:: https://img.shields.io/pypi/pyversions/energydram
        :target: https://pypi.org/project/energydram/

:Test status:
    .. image:: https://github.com/gaomy3832/energydram/actions/workflows/test.yml/badge.svg?branch=master
        :target: https://github.com/gaomy3832/energydram/actions/workflows/test.yml

    .. image:: https://codecov.io/gh/gaomy3832/energydram/branch/master/graph/badge.svg?token=V3L3RF3VND
        :target: https://codecov.io/gh/gaomy3832/energydram

DRAM energy calculation.

Current supported standards:

- DDR2/3/4
- LPDDR2/3/4
- GDDR5 (only for termination)

by *Mingyu Gao*


References
----------

Micron, Calculating Memory System Power for DDR3, tech note TN-41-01.

Micron, Calculating Memory Power for DDR4 SDRAM, tech note TN-40-07.

N. Jouppi, A. B. Kahng, N. Muralimanohar and V. Srinivas, CACTI-IO: CACTI With
Off-Chip Power-Area-Timing Models, IEEE Transactions on Very Large Scale
Integration (VLSI) Systems 23(7) (2015), pp. 1254-1267.

